@@ -19,7 +19,7 @@ where the beam is
 import logging
 import math
 from dataclasses import dataclass
-from typing import Any, Dict, List, Optional, Set, Tuple, Union
+from typing import Any, Optional, Union
 
 import networkx as nx
 from happi import Client, SearchResult
@@ -35,7 +35,7 @@ from .path import BeamPath
 logger = logging.getLogger(__name__)
 
 NodeName = str
-MaybeBeamPath = List[Union[List[NodeName], BeamPath]]
+MaybeBeamPath = list[Union[list[NodeName], BeamPath]]
 
 
 @dataclass
@@ -65,8 +65,8 @@ class LightController:
     def __init__(
         self,
         client: Client,
-        endstations: Optional[List[str]] = None,
-        cfg: Dict[str, Any] = {}
+        endstations: Optional[list[str]] = None,
+        cfg: dict[str, Any] = {}
     ):
         self.client: Client = client
         config = {
@@ -83,9 +83,9 @@ class LightController:
         self.min_trans = config['min_trans']
 
         # a mapping of endstation name to either a path or initialized BeamPath
-        self.beamlines: Dict[str, MaybeBeamPath] = dict()
+        self.beamlines: dict[str, MaybeBeamPath] = dict()
         # sources found in facility
-        self.sources: Set[str] = set()
+        self.sources: set[str] = set()
 
         # initialize graph -> self.graph
         self.load_facility()
@@ -116,10 +116,11 @@ class LightController:
             for branch_set in (res.metadata.get('input_branches', []),
                                res.metadata.get('output_branches', [])):
                 if branch_set is None:
-                    raise ValueError(
-                        f'device {res.item.name} has no branch information, '
+                    logger.warning(
+                        f'device ({res.item.name}) missing branch information, '
                         'check to make sure your happi database is '
                         'correctly implementing its container.')
+                    break
                 for branch in branch_set:
                     branch_dict.setdefault(branch, set()).add(res)
 
@@ -131,8 +132,8 @@ class LightController:
                 sources=self.default_sources,
                 branch_name=branch_name
             )
-            self.sources.update((n for n in subgraph
-                                 if self.is_source_name(n)))
+            self.sources.update(n for n in subgraph
+                                if self.is_source_name(n))
             subgraphs.append(subgraph)
 
         self.graph = nx.compose_all(subgraphs)
@@ -146,7 +147,7 @@ class LightController:
         consider part of the path.
 
         Loads valid beampaths into the LightController.beamlines
-        attribute for latedr access.
+        attribute for later access.
 
         Parameters
         ----------
@@ -165,20 +166,48 @@ class LightController:
             # Find the paths from each source to the desired line
             for src in self.sources:
                 try:
-                    if nx.has_path(self.graph, src, branch):
-                        found_paths = nx.all_simple_paths(self.graph,
-                                                          source=src,
-                                                          target=branch)
-                        paths.extend(found_paths)
-                    else:
-                        logger.debug(f'No path between {src} and {branch}')
+                    path_exists: bool = nx.has_path(self.graph, src, branch)
                 except NodeNotFound:
                     logger.debug(f'Either source {src} or target {branch} '
                                  'not found.')
+                    path_exists = False
 
-        self.beamlines[endstation] = paths
+                if path_exists:
+                    found_paths = nx.all_simple_paths(self.graph,
+                                                      source=src,
+                                                      target=branch)
 
-    def get_paths(self, endstation: str) -> List[BeamPath]:
+                    # Trim beamline based on z-positions
+                    if isinstance(end_branches, dict):
+                        new_paths = list()
+                        for found_path in found_paths:
+                            end_z = end_branches[branch]
+                            if end_z is not None:
+                                # Only filter internal devices
+                                truncated_path = [
+                                    name for name in found_path[1:-1]
+                                    if self.graph.nodes[name]['md'].res['z'] < end_z
+                                ]
+                                truncated_path.append(found_path[-1])
+                                truncated_path.insert(0, found_path[0])
+                                new_paths.append(truncated_path)
+                            else:
+                                new_paths.append(found_path)
+
+                        paths.extend(new_paths)
+                    elif isinstance(end_branches, list):
+                        paths.extend(found_paths)
+                    else:
+                        raise TypeError('config is incorrectly formatted '
+                                        f'(found mapping from {endstation} to '
+                                        f'{type(end_branches)}).')
+
+                else:
+                    logger.debug(f'No path between {src} and {branch}')
+
+                self.beamlines[endstation] = paths
+
+    def get_paths(self, endstation: str) -> list[BeamPath]:
         """
         Returns the BeamPaths for a specified endstation.
         Create and fill the BeamPaths if they have not been already
@@ -200,7 +229,7 @@ class LightController:
             return paths
 
         # create the BeamPaths if they have not been already
-        end_branches = self.beamline_config[endstation]
+        # end_branches = self.beamline_config[endstation]
         filled_paths = []
         for path in paths:
             subgraph = self.graph.subgraph(path)
@@ -213,23 +242,7 @@ class LightController:
                 minimum_transmission=self.min_trans
             )
 
-            if isinstance(end_branches, dict):
-                # access the last z for this branch
-                # if end_branches is Dict[BranchName, end_z], grab last
-                # allowable z with the branch name (last node in path)
-                last_z = end_branches[path[-1]]
-                if last_z:
-                    # append path with all devices before last z
-                    filled_paths.append(bp.split(last_z)[0])
-                else:
-                    filled_paths.append(bp)
-            elif isinstance(end_branches, list):
-                # end_branches is a simple list, no splitting needed
-                filled_paths.append(bp)
-            else:
-                raise TypeError('config is incorrectly formatted '
-                                f'(found mapping from {endstation} to '
-                                f'{type(end_branches)}).')
+            filled_paths.append(bp)
 
         self.beamlines[endstation] = filled_paths
         return filled_paths
@@ -295,7 +308,7 @@ class LightController:
         """
         return name.startswith('source_')
 
-    def walk_facility(self) -> Dict[NodeName, List[NodeName]]:
+    def walk_facility(self) -> dict[NodeName, list[NodeName]]:
         """
         Return the paths from each source to its destination by walking the
         graph.
@@ -318,7 +331,7 @@ class LightController:
         PathError
             If a single, valid path cannot be determined
         """
-        paths: Dict[NodeName, List] = {k: [] for k in self.sources}
+        paths: dict[NodeName, list] = {k: [] for k in self.sources}
 
         for src, path in paths.items():
             successors = list(self.graph.successors(src))
@@ -365,7 +378,7 @@ class LightController:
         return paths
 
     @property
-    def destinations(self) -> List[Device]:
+    def destinations(self) -> list[Device]:
         """
         Current device destinations for the LCLS photon beam
 
@@ -391,7 +404,7 @@ class LightController:
         return list(dests)
 
     @property
-    def devices(self) -> List[Device]:
+    def devices(self) -> list[Device]:
         """
         All of the devices loaded in the facility
 
@@ -403,7 +416,7 @@ class LightController:
         return [n[1]['md'].dev for n in self.graph.nodes.data()]
 
     @property
-    def incident_devices(self) -> List[Device]:
+    def incident_devices(self) -> list[Device]:
         """
         List of all devices in contact with photons along the beamline
 
@@ -421,7 +434,7 @@ class LightController:
 
         return list(devices)
 
-    def paths_to(self, device: Device) -> List[BeamPath]:
+    def paths_to(self, device: Device) -> list[BeamPath]:
         """
         Create all BeamPaths from the facility source to the requested device
 
@@ -488,9 +501,9 @@ class LightController:
 
     @staticmethod
     def make_graph(
-        branch_devs: List[SearchResult],
+        branch_devs: list[SearchResult],
         branch_name: str,
-        sources: List[NodeName] = []
+        sources: list[NodeName] = []
     ) -> nx.DiGraph:
         """
         Create a graph with devices from ``branch_devs`` as nodes,
@@ -528,9 +541,9 @@ class LightController:
                          {'md': NodeMetadata(res=res, dev=None)}))
 
         # construct edges
-        edges: List[Tuple[NodeName, NodeName, Dict[str, Any]]] = []
-        skipped_right: List[int] = []
-        skipped_left: List[int] = []
+        edges: list[tuple[NodeName, NodeName, dict[str, Any]]] = []
+        skipped_right: list[int] = []
+        skipped_left: list[int] = []
         last_on_branch = 0
         # weight not used currently, but may be for path finding algos
         edata = {'weight': 0.0, 'branch': branch_name}
@@ -638,7 +651,7 @@ class LightController:
                 return dev
 
 
-def get_active_outputs(device: Device) -> List[str]:
+def get_active_outputs(device: Device) -> list[str]:
     """
     Returns a list of branch names that are receiving beam.
     Alternatively, returns a list of branches this device is delivering
