@@ -1,6 +1,7 @@
 import logging
 import os.path
 import sys
+import time
 from contextlib import contextmanager
 
 import happi
@@ -32,7 +33,7 @@ def set_level(pytestconfig):
 
     # Report invalid logging level
     if not isinstance(log_level, int):
-        raise ValueError("Invalid log level : {}".format(log_level))
+        raise ValueError(f"Invalid log level : {log_level}")
 
     # Create basic configuration
     logging.basicConfig(level=log_level,
@@ -42,6 +43,14 @@ def set_level(pytestconfig):
 ############
 # Fixtures #
 ############
+def wait_until(condition: callable, interval=0.1, timeout=1, *args, **kwargs):
+    start = time.time()
+    while not condition(*args, **kwargs) and time.time() - start < timeout:
+        time.sleep(interval)
+
+    print(f'{time.time() - start:.3} s elapsed')
+
+
 # Basic Device
 @pytest.fixture(scope='function')
 def device():
@@ -181,7 +190,7 @@ def lcls_ctrl(lcls_client: happi.Client):
 @pytest.fixture(scope='function')
 def cfg():
     cfg_path = os.path.join(os.path.dirname(__file__), 'conf.yml')
-    with open(cfg_path, 'r') as f:
+    with open(cfg_path) as f:
         cfg = yaml.safe_load(f)
 
     return cfg
