@@ -1,5 +1,6 @@
 import io
 import re
+import time
 from unittest.mock import Mock
 
 from ophyd.device import Device
@@ -7,6 +8,7 @@ from ophyd.device import Device
 from lightpath import BeamPath
 from lightpath.mock_devices import Crystal, Status
 from lightpath.path import DeviceState, find_device_state
+from lightpath.tests.conftest import wait_until
 
 
 def raiser(*args, **kwargs):
@@ -203,7 +205,9 @@ def test_callback(path: BeamPath):
     path.subscribe(cb, run=False)
     # Change state of beampath
     path.devices[4].insert()
+    time.sleep(0.2)
     # Assert callback has been run
+    wait_until(lambda: cb.called)
     assert cb.called
 
 
