@@ -78,8 +78,7 @@ class LightApp(Display):
             self.destination_combo.addItem(line)
 
         # Connect signals to slots
-        self.destination_combo.currentIndexChanged.connect(
-                                            self.change_path_display)
+        self.destination_combo.currentIndexChanged.connect(self.change_path_display)
         self.device_combo.activated[str].connect(self.focus_on_device)
         self.impediment_button.pressed.connect(self.focus_on_device)
         self.upstream_device_combo.activated[str].connect(self.update_upstream)
@@ -239,11 +238,12 @@ class LightApp(Display):
                 self.overview.layout().addWidget(row[1])
                 # Connect condensed widget to focus_on_device
                 row[1].device_drawing.clicked.connect(
-                        partial(self.focus_on_device,
-                                name=row[1].device.name))
+                    partial(self.focus_on_device, name=row[1].device.name)
+                )
                 # Connect large widget to show Typhos screen
                 row[0].device_drawing.clicked.connect(
-                        partial(self.show_detailed, row[0].device))
+                    partial(self.show_detailed, row[0].device)
+                )
                 # Add device to combo
                 self.device_combo.addItem(row[0].device.name)
                 self.upstream_device_combo.addItem(row[0].device.name)
@@ -255,6 +255,8 @@ class LightApp(Display):
         self.update_path()
         # Update device type checkboxes
         self.update_device_types()
+        # re-filter based on present settings
+        self.filter()
         self.setWindowTitle(f'Lightpath - {self.selected_beamline()}')
 
     @contextlib.contextmanager
@@ -291,7 +293,7 @@ class LightApp(Display):
         return os.path.join(os.path.dirname(os.path.abspath(__file__)),
                             self.ui_filename())
 
-    def update_path(self, *args,  **kwargs):
+    def update_path(self, *args, **kwargs):
         """
         Update the PyDMRectangles to show devices as in the beam or not
         """
@@ -365,7 +367,7 @@ class LightApp(Display):
             # Hide if a hidden instance of a device type
             hidden_device_type = any([device.__module__ == dtype
                                       for dtype in self.hidden_devices])
-            # Hide if removed
+            # Hide if removed (checked if showing removed devices)
             hidden_removed = (not self.remove_check.isChecked()
                               and row[0].last_state == DeviceState.Removed)
             # Hide if upstream
